@@ -1,5 +1,3 @@
-has_node <- unname(nchar(Sys.which("node")) > 0L)
-
 test_that("as_vegaspec translates", {
 
   # need to go to json and back because of data-frame in vw_ex_mtcars
@@ -17,13 +15,11 @@ test_that("class is correct", {
   expect_s3_class(as_vegaspec(unclass(spec_mtcars)), "vegaspec")
   expect_s3_class(as_vegaspec(unclass(spec_mtcars)), "vegaspec_vega_lite")
 
-  # Need to have node installed
-  skip_on_cran()
-  skip_if_not(has_node)
+  spec_mtcars_vega <- vw_to_vega(spec_mtcars)
 
-  expect_type(vw_to_vega(spec_mtcars), "list")
-  expect_s3_class(vw_to_vega(spec_mtcars), "vegaspec")
-  expect_s3_class(vw_to_vega(spec_mtcars), "vegaspec_vega")
+  expect_type(spec_mtcars_vega, "list")
+  expect_s3_class(spec_mtcars_vega, "vegaspec")
+  expect_s3_class(spec_mtcars_vega, "vegaspec_vega")
 
 })
 
@@ -85,7 +81,15 @@ test_that("as_vegaspec reads UTF-8 correctly", {
 
 })
 
+test_that("as_vegaspec reads urls correctly", {
 
+  skip_on_cran()
+
+  myspec <- as_vegaspec("https://raw.githubusercontent.com/vega/vega-lite/master/examples/specs/bar.vl.json")
+
+  expect_s3_class(myspec, "vegaspec_vega_lite")
+
+})
 
 
 
